@@ -25,6 +25,7 @@ from pytensor.tensor.basic import (
     constant,
     extract_constant,
     get_underlying_scalar_constant_value,
+    register_infer_shape,
     stack,
 )
 from pytensor.tensor.elemwise import DimShuffle, Elemwise
@@ -964,6 +965,7 @@ def local_reshape_lift(fgraph, node):
         return [e]
 
 
+@register_infer_shape
 @register_useless
 @register_canonicalize
 @node_rewriter([SpecifyShape])
@@ -990,6 +992,17 @@ def local_merge_consecutive_specify_shape(fgraph, node):
     return [specify_shape(inner_obj, shape)]
 
 
+@register_infer_shape
+@node_rewriter([Shape])
+def local_shape_ground(fgraph, node):
+    """Rewrite shape(x) -> make_vector(x.type.shape) when this is constant."""
+    [x] = node.inputs
+    static_shape = x.type.shape
+    if not any(dim is None for dim in static_shape):
+        return [stack([constant(dim, dtype="int64") for dim in static_shape])]
+
+
+@register_infer_shape
 @register_useless
 @register_canonicalize
 @node_rewriter([Shape])
@@ -1014,6 +1027,7 @@ def local_Shape_of_SpecifyShape(fgraph, node):
     return [stack(shape).astype(np.int64)]
 
 
+@register_infer_shape
 @register_canonicalize
 @register_specialize
 @node_rewriter([SpecifyShape])
@@ -1060,6 +1074,7 @@ def local_specify_shape_lift(fgraph, node):
         return new_out
 
 
+@register_infer_shape
 @register_useless
 @register_canonicalize
 @node_rewriter([Shape_i])
@@ -1079,6 +1094,7 @@ def local_Shape_i_ground(fgraph, node):
         return [as_tensor_variable(s_val, dtype=np.int64)]
 
 
+@register_infer_shape
 @register_specialize
 @register_canonicalize
 @node_rewriter([Shape])
